@@ -2,7 +2,7 @@
 
 __author__ = """MIT Data To AI Lab"""
 __email__ = 'dailabmit@gmail.com'
-__version__ = '0.1.2'
+__version__ = '0.1.3'
 
 import os
 
@@ -11,7 +11,10 @@ from orion.functional import detect_anomalies, evaluate_pipeline, fit_pipeline
 
 _BASE_PATH = os.path.abspath(os.path.dirname(__file__))
 MLBLOCKS_PRIMITIVES = os.path.join(_BASE_PATH, 'primitives', 'jsons')
-MLBLOCKS_PIPELINES = os.path.join(_BASE_PATH, 'pipelines')
+MLBLOCKS_PIPELINES = tuple(
+    dirname
+    for dirname, _, _ in os.walk(os.path.join(_BASE_PATH, 'pipelines'))
+)
 
 __all__ = (
     'Orion',
